Function seal
Source pub fn seal<T: Serialize>(
obj: &T,
key: &SealingKey,
aad: impl AsRef<[u8]>,
) -> Result<Vec<u8>>
Encodes and encrypts the given obj with additional associated data (or b"" if None).
Use unseal to revert.
Uses a non self-describing encoding format for T, so seal is not suitable for long-lived
data that might change.